[−][src]Struct lastpass::Attachment
Metadata about an attached file.
Fields (Non-exhaustive)
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: Idparent: IdThe ID of the parent crate::Account.
mime_type: StringThe file's mimetype.
storage_key: StringAn opaque string which is used by the backend to find the correct version of an attached file.
Note: uploading a new version will change the storage key, but the attachment's ID stays the same.
size: u64The size of the attachment, in bytes.
encrypted_filename: StringThe attachment's filename, encrypted using the account's
attachment_key.
Methods
impl Attachment[src]
pub fn filename(
&self,
decryption_key: &DecryptionKey
) -> Result<String, DecryptionError>[src]
&self,
decryption_key: &DecryptionKey
) -> Result<String, DecryptionError>